==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UserGroupsFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link UserGroups}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class UserGroupsFieldAttributes extends AbstractBeanAttributesDefinition{

    /** groups (Database column: GROUPID) */
    static public AttributeDefinition groups =
        new AttributeDefinition("groups")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_GROUPS")
                .setDatabaseId("GROUPID")
                .setMandatory(true)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_GROUPS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** users (Database column: USERID) */
    static public AttributeDefinition users =
        new AttributeDefinition("users")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_GROUPS")
                .setDatabaseId("USERID")
                .setMandatory(true)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Users.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Users.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(groups.getName(),groups);
        map.put(id.getName(),id);
        map.put(users.getName(),users);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UserGroupsFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link UserGroups}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class UserGroupsFieldAttributes extends AbstractBeanAttributesDefinition{

    /** groups (Database column: GROUPID) */
    static public AttributeDefinition groups =
        new AttributeDefinition("groups")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_GROUPS")
                .setDatabaseId("GROUPID")
                .setMandatory(false)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_GROUPS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(9)
                .setType(Long.class);

    /** users (Database column: USERID) */
    static public AttributeDefinition users =
        new AttributeDefinition("users")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_GROUPS")
                .setDatabaseId("USERID")
                .setMandatory(false)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Users.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Users.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(groups.getName(),groups);
        map.put(id.getName(),id);
        map.put(users.getName(),users);

        return map;
    }
}
